==> camel-k-model-v1-6.2.0-sources.jar: io/fabric8/camelk/v1/IntegrationKitSpecFluent.java <==
package io.fabric8.camelk.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface IntegrationKitSpecFluent<A extends IntegrationKitSpecFluent<A>> extends Fluent<A>{
  public A addToConfiguration(Integer index,ConfigurationSpec item);
  public A setToConfiguration(Integer index,ConfigurationSpec item);
  public A addToConfiguration(io.fabric8.camelk.v1.ConfigurationSpec... items);
  public A addAllToConfiguration(Collection<ConfigurationSpec> items);
  public A removeFromConfiguration(io.fabric8.camelk.v1.ConfigurationSpec... items);
  public A removeAllFromConfiguration(Collection<ConfigurationSpec> items);
  public A removeMatchingFromConfiguration(Predicate<ConfigurationSpecBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConfiguration instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ConfigurationSpec> getConfiguration();
  public List<ConfigurationSpec> buildConfiguration();
  public ConfigurationSpec buildConfiguration(Integer index);
  public ConfigurationSpec buildFirstConfiguration();
  public ConfigurationSpec buildLastConfiguration();
  public ConfigurationSpec buildMatchingConfiguration(Predicate<ConfigurationSpecBuilder> predicate);
  public Boolean hasMatchingConfiguration(Predicate<ConfigurationSpecBuilder> predicate);
  public A withConfiguration(List<ConfigurationSpec> configuration);
  public A withConfiguration(io.fabric8.camelk.v1.ConfigurationSpec... configuration);
  public Boolean hasConfiguration();
  public A addNewConfiguration(String resourceKey,String resourceMountPoint,String resourceType,String type,String value);
  public IntegrationKitSpecFluent.ConfigurationNested<A> addNewConfiguration();
  public IntegrationKitSpecFluent.ConfigurationNested<A> addNewConfigurationLike(ConfigurationSpec item);
  public IntegrationKitSpecFluent.ConfigurationNested<A> setNewConfigurationLike(Integer index,ConfigurationSpec item);
  public IntegrationKitSpecFluent.ConfigurationNested<A> editConfiguration(Integer index);
  public IntegrationKitSpecFluent.ConfigurationNested<A> editFirstConfiguration();
  public IntegrationKitSpecFluent.ConfigurationNested<A> editLastConfiguration();
  public IntegrationKitSpecFluent.ConfigurationNested<A> editMatchingConfiguration(Predicate<ConfigurationSpecBuilder> predicate);
  public A addToDependencies(Integer index,String item);
  public A setToDependencies(Integer index,String item);
  public A addToDependencies(java.lang.String... items);
  public A addAllToDependencies(Collection<String> items);
  public A removeFromDependencies(java.lang.String... items);
  public A removeAllFromDependencies(Collection<String> items);
  public List<String> getDependencies();
  public String getDependency(Integer index);
  public String getFirstDependency();
  public String getLastDependency();
  public String getMatchingDependency(Predicate<String> predicate);
  public Boolean hasMatchingDependency(Predicate<String> predicate);
  public A withDependencies(List<String> dependencies);
  public A withDependencies(java.lang.String... dependencies);
  public Boolean hasDependencies();
  public String getImage();
  public A withImage(String image);
  public Boolean hasImage();
  public String getProfile();
  public A withProfile(String profile);
  public Boolean hasProfile();
  public A addToRepositories(Integer index,String item);
  public A setToRepositories(Integer index,String item);
  public A addToRepositories(java.lang.String... items);
  public A addAllToRepositories(Collection<String> items);
  public A removeFromRepositories(java.lang.String... items);
  public A removeAllFromRepositories(Collection<String> items);
  public List<String> getRepositories();
  public String getRepository(Integer index);
  public String getFirstRepository();
  public String getLastRepository();
  public String getMatchingRepository(Predicate<String> predicate);
  public Boolean hasMatchingRepository(Predicate<String> predicate);
  public A withRepositories(List<String> repositories);
  public A withRepositories(java.lang.String... repositories);
  public Boolean hasRepositories();
  public A addToTraits(String key,TraitSpec value);
  public A addToTraits(Map<String,TraitSpec> map);
  public A removeFromTraits(String key);
  public A removeFromTraits(Map<String,TraitSpec> map);
  public Map<String,TraitSpec> getTraits();
  public <K,V>A withTraits(Map<String,TraitSpec> traits);
  public Boolean hasTraits();
  public interface ConfigurationNested<N> extends Nested<N>,ConfigurationSpecFluent<IntegrationKitSpecFluent.ConfigurationNested<N>>{
    public N and();
    public N endConfiguration();
    
  }
  
}

==> camel-k-model-v1-6.7.2-sources.jar: io/fabric8/camelk/v1/IntegrationKitSpecFluent.java <==
package io.fabric8.camelk.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface IntegrationKitSpecFluent<A extends IntegrationKitSpecFluent<A>> extends Fluent<A>{
  public A addToConfiguration(int index,ConfigurationSpec item);
  public A setToConfiguration(int index,ConfigurationSpec item);
  public A addToConfiguration(io.fabric8.camelk.v1.ConfigurationSpec... items);
  public A addAllToConfiguration(Collection<ConfigurationSpec> items);
  public A removeFromConfiguration(io.fabric8.camelk.v1.ConfigurationSpec... items);
  public A removeAllFromConfiguration(Collection<ConfigurationSpec> items);
  public A removeMatchingFromConfiguration(Predicate<ConfigurationSpecBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConfiguration instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ConfigurationSpec> getConfiguration();
  public List<ConfigurationSpec> buildConfiguration();
  public ConfigurationSpec buildConfiguration(int index);
  public ConfigurationSpec buildFirstConfiguration();
  public ConfigurationSpec buildLastConfiguration();
  public ConfigurationSpec buildMatchingConfiguration(Predicate<ConfigurationSpecBuilder> predicate);
  public Boolean hasMatchingConfiguration(Predicate<ConfigurationSpecBuilder> predicate);
  public A withConfiguration(List<ConfigurationSpec> configuration);
  public A withConfiguration(io.fabric8.camelk.v1.ConfigurationSpec... configuration);
  public Boolean hasConfiguration();
  public A addNewConfiguration(String resourceKey,String resourceMountPoint,String resourceType,String type,String value);
  public IntegrationKitSpecFluent.ConfigurationNested<A> addNewConfiguration();
  public IntegrationKitSpecFluent.ConfigurationNested<A> addNewConfigurationLike(ConfigurationSpec item);
  public IntegrationKitSpecFluent.ConfigurationNested<A> setNewConfigurationLike(int index,ConfigurationSpec item);
  public IntegrationKitSpecFluent.ConfigurationNested<A> editConfiguration(int index);
  public IntegrationKitSpecFluent.ConfigurationNested<A> editFirstConfiguration();
  public IntegrationKitSpecFluent.ConfigurationNested<A> editLastConfiguration();
  public IntegrationKitSpecFluent.ConfigurationNested<A> editMatchingConfiguration(Predicate<ConfigurationSpecBuilder> predicate);
  public A addToDependencies(int index,String item);
  public A setToDependencies(int index,String item);
  public A addToDependencies(java.lang.String... items);
  public A addAllToDependencies(Collection<String> items);
  public A removeFromDependencies(java.lang.String... items);
  public A removeAllFromDependencies(Collection<String> items);
  public List<String> getDependencies();
  public String getDependency(int index);
  public String getFirstDependency();
  public String getLastDependency();
  public String getMatchingDependency(Predicate<String> predicate);
  public Boolean hasMatchingDependency(Predicate<String> predicate);
  public A withDependencies(List<String> dependencies);
  public A withDependencies(java.lang.String... dependencies);
  public Boolean hasDependencies();
  public String getImage();
  public A withImage(String image);
  public Boolean hasImage();
  public String getProfile();
  public A withProfile(String profile);
  public Boolean hasProfile();
  public A addToRepositories(int index,String item);
  public A setToRepositories(int index,String item);
  public A addToRepositories(java.lang.String... items);
  public A addAllToRepositories(Collection<String> items);
  public A removeFromRepositories(java.lang.String... items);
  public A removeAllFromRepositories(Collection<String> items);
  public List<String> getRepositories();
  public String getRepository(int index);
  public String getFirstRepository();
  public String getLastRepository();
  public String getMatchingRepository(Predicate<String> predicate);
  public Boolean hasMatchingRepository(Predicate<String> predicate);
  public A withRepositories(List<String> repositories);
  public A withRepositories(java.lang.String... repositories);
  public Boolean hasRepositories();
  public A addToTraits(String key,TraitSpec value);
  public A addToTraits(Map<String,TraitSpec> map);
  public A removeFromTraits(String key);
  public A removeFromTraits(Map<String,TraitSpec> map);
  public Map<String,TraitSpec> getTraits();
  public <K,V>A withTraits(Map<String,TraitSpec> traits);
  public Boolean hasTraits();
  public interface ConfigurationNested<N> extends Nested<N>,ConfigurationSpecFluent<IntegrationKitSpecFluent.ConfigurationNested<N>>{
    public N and();
    public N endConfiguration();
    
  }
  
}
